# Devenvcp

Template init tool for devenv inspired by nix flake init to copy your devenv templates so you don't need to use nix flakes for it.

## Installation
### From Pypi
```sh
pip install devenvcp
```

### From nix flake
Add this to your inputs
```nix
inputs.devenvcp.url = "git+https://codeberg.org/claymorwan/devenvcp"
```
Then install the package like so:
```nix
environment.systemPackages = [
  inputs.devenvcp.packages.${pkgs.stdenv.hostPlatform.system}.default
];
```
for home-manager:
```nix
home.packages = [
  inputs.devenvcp.packages.${pkgs.stdenv.hostPlatform.system}.default
];
```

You can also directly run
```sh
nix run git+https://codeberg.org/claymorwan/devenvcp -- <args>
```

## Usage
Create a `devenvcp.toml` file in which you can add your templates like so
```toml
[python]            # name of template
path = "./python"   # relative path your template's directory
aliases = ["py"]    # list of string to use as aliases in the cli
```

Then run the following
```sh
devenvcp path/to/dir/containing/config template
# for example
devenvcp ~/.dotfiles/NixOS/dev-shells/devenv python
```

### Wait can't I just use this with anything else and not just devenv ?

I mean yea, I made it with devenv in mind at first but nothing stops u from using it with to template like anything else lol, I might rename the project eventually who knows
